==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnFilterOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnFilterOptionsDescription } from "./GridColumnFilterOptionsDescription";
/**
 * @hidden
 */
export let GridColumnFilterOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnFilterOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnFilterOptionsDescriptionMetadata.a == null) {
                GridColumnFilterOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnFilterOptionsDescriptionMetadata.c(GridColumnFilterOptionsDescriptionMetadata.a);
            }
            if (a.j(GridColumnFilterOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnFilterOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("ClearColumnFiltersCaption", "String");
            a.item("FilterListPlaceholderText", "String");
            a.item("FilterListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("FilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
            a.item("ActualFilterListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("ActualFilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
            a.item("TextFilterCaption", "String");
        }
        static d(a) {
            GridColumnFilterOptionsDescriptionMetadata.b(a);
            a.aa("GridColumnFilterOptions", () => new GridColumnFilterOptionsDescription());
            a.z("GridColumnFilterOptions", GridColumnFilterOptionsDescriptionMetadata.a);
        }
    }
    GridColumnFilterOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnFilterOptionsDescriptionMetadata, 'GridColumnFilterOptionsDescriptionMetadata');
    GridColumnFilterOptionsDescriptionMetadata.a = null;
    return GridColumnFilterOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnFilterOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnFilterOptionsDescription } from "./GridColumnFilterOptionsDescription";
/**
 * @hidden
 */
export let GridColumnFilterOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnFilterOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnFilterOptionsDescriptionMetadata.a == null) {
                GridColumnFilterOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnFilterOptionsDescriptionMetadata.c(GridColumnFilterOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnFilterOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnFilterOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("ClearColumnFiltersCaption", "String");
            a.item("FilterListPlaceholderText", "String");
            a.item("FilterListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("FilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
            a.item("ActualFilterListDensity", "ExportedType:string:ControlDisplayDensity");
            a.item("ActualFilterListDensity@names", "Auto;Comfortable;Cosy;Compact");
            a.item("TextFilterCaption", "String");
        }
        static d(a) {
            GridColumnFilterOptionsDescriptionMetadata.b(a);
            a.ac("GridColumnFilterOptions", () => new GridColumnFilterOptionsDescription());
            a.ab("GridColumnFilterOptions", GridColumnFilterOptionsDescriptionMetadata.a);
        }
    }
    GridColumnFilterOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnFilterOptionsDescriptionMetadata, 'GridColumnFilterOptionsDescriptionMetadata');
    GridColumnFilterOptionsDescriptionMetadata.a = null;
    return GridColumnFilterOptionsDescriptionMetadata;
})();
